@@ -1,9 +1,9 @@
 #!/usr/bin/env python
-# -*- coding: utf-8 -*-
-from __future__ import unicode_literals
 
 import sys
-from pathlib import PurePath
+from pathlib import Path, PurePath
+
+import pytest
 
 from dparse.errors import MalformedDependencyFileError
 
@@ -35,6 +35,7 @@ def test_tox_ini_with_invalid_requirement():
     assert len(dep_file.dependencies) == 0
 
 
+@pytest.mark.conda
 def test_conda_file_with_invalid_requirement():
 
     content = "name: my_env\n" \
@@ -45,14 +46,14 @@ def test_conda_file_with_invalid_requirement():
     dep_file = parse(content, file_type=filetypes.conda_yml)
     assert len(dep_file.dependencies) == 0
 
-
+@pytest.mark.conda
 def test_conda_file_invalid_yml():
 
     content = "wawth:dda : awd:\ndlll"
     dep_file = parse(content, file_type=filetypes.conda_yml)
     assert dep_file.dependencies == []
 
-
+@pytest.mark.conda
 def test_conda_file_marked_line():
     content = "name: my_env\n" \
               "dependencies:\n" \
@@ -85,11 +86,13 @@ def test_tox_ini_marked_line():
 
 
 def test_resolve_file():
+    req_path = str(Path("/req.txt"))
+
     line = "-r req.txt"
-    assert Parser.resolve_file("/", line) == "/req.txt"
+    assert Parser.resolve_file("/", line) == req_path
 
     line = "-r req.txt # mysterious comment"
-    assert Parser.resolve_file("/", line) == "/req.txt"
+    assert Parser.resolve_file("/", line) == req_path
 
     line = "-r req.txt"
     assert Parser.resolve_file("", line) == "req.txt"
@@ -180,12 +183,15 @@ def test_requirements_parse_unsupported_line_start():
 def test_file_resolver():
     content = "-r production/requirements.txt\n" \
               "--requirement test.txt\n"
+    
+    req_path = str(Path("/production/requirements.txt"))
+    test_path = str(Path("/test.txt"))
 
     dep_file = parse(content=content, path="/", file_type=filetypes.requirements_txt)
 
     assert dep_file.resolved_files == [
-        "/production/requirements.txt",
-        "/test.txt"
+        req_path,
+        test_path
     ]
 
     dep_file = parse(content=content, file_type=filetypes.requirements_txt)
@@ -331,7 +337,7 @@ def test_pipfile_lock_with_invalid_json():
     assert isinstance(throw, MalformedDependencyFileError)
 
 
-def test_poetry_lock():
+def test_poetry_lock_version_lower_than_1_5():
     content = """
     [[package]]
     name = "certifi"
@@ -370,13 +376,13 @@ def test_poetry_lock():
     assert dep_file.dependencies[0].name == 'certifi'
     assert dep_file.dependencies[0].specs == SpecifierSet('==2022.6.15')
     assert dep_file.dependencies[0].dependency_type == 'poetry.lock'
-    assert dep_file.dependencies[0].section == 'main'
+    assert dep_file.dependencies[0].sections == ['main']
     assert dep_file.dependencies[0].hashes == ()
 
     assert dep_file.dependencies[1].name == 'attrs'
     assert dep_file.dependencies[1].specs == SpecifierSet('==22.1.0')
     assert dep_file.dependencies[1].dependency_type == 'poetry.lock'
-    assert dep_file.dependencies[1].section == 'dev'
+    assert dep_file.dependencies[1].sections == ['dev']
     assert dep_file.dependencies[1].hashes == ()
 
 
@@ -407,3 +413,174 @@ def test_poetry_lock_with_invalid_toml():
         throw = e
 
     assert isinstance(throw, MalformedDependencyFileError)
+
+
+def test_poetry_lock_version_greater_than_1_5():
+    """In poetry's version 1.5, the `category` field was removed. We need then to be able to handle such scenario."""
+
+    content = """
+    [[package]]
+    name = "certifi"
+    version = "2022.6.15"
+    description = "Python package for providing Mozilla's CA Bundle."
+    optional = false
+    python-versions = ">=3.6"
+
+    [[package]]
+    name = "attrs"
+    version = "22.1.0"
+    description = "Classes Without Boilerplate"
+    optional = false
+    python-versions = ">=3.5"
+
+    [package.extras]
+    dev = ["coverage[toml] (>=5.0.2)", "hypothesis", "pympler", "pytest (>=4.3.0)", "mypy (>=0.900,!=0.940)", "pytest-mypy-plugins", "zope.interface", "furo", "sphinx", "sphinx-notfound-page", "pre-commit", "cloudpickle"]
+    docs = ["furo", "sphinx", "zope.interface", "sphinx-notfound-page"]
+    tests = ["coverage[toml] (>=5.0.2)", "hypothesis", "pympler", "pytest (>=4.3.0)", "mypy (>=0.900,!=0.940)", "pytest-mypy-plugins", "zope.interface", "cloudpickle"]
+    tests_no_zope = ["coverage[toml] (>=5.0.2)", "hypothesis", "pympler", "pytest (>=4.3.0)", "mypy (>=0.900,!=0.940)", "pytest-mypy-plugins", "cloudpickle"]
+
+    [metadata]
+    lock-version = "1.1"
+    python-versions = "^3.9"
+    content-hash = "96e49f07dcfd53e21489b9a7f3451d3b76515f33496173d989395e1898ae9a26"
+
+    [metadata.files]
+    certifi = []
+    attrs = []
+    """
+
+    dep_file = parse(content, file_type=filetypes.poetry_lock)
+
+    assert dep_file.dependencies[0].name == 'certifi'
+    assert dep_file.dependencies[0].specs == SpecifierSet('==2022.6.15')
+    assert dep_file.dependencies[0].dependency_type == 'poetry.lock'
+    assert dep_file.dependencies[0].sections == []
+    assert dep_file.dependencies[0].hashes == ()
+
+    assert dep_file.dependencies[1].name == 'attrs'
+    assert dep_file.dependencies[1].specs == SpecifierSet('==22.1.0')
+    assert dep_file.dependencies[1].dependency_type == 'poetry.lock'
+    assert dep_file.dependencies[1].sections == []
+    assert dep_file.dependencies[1].hashes == ()
+
+
+def test_pyproject_toml() -> None:
+    content = """
+    [project]
+    name = "my_package"
+    authors = [
+        {name = "John Doe", email = "john.doe@email"},
+    ]
+    description = "My package description"
+    dependencies = [
+        "requests",
+        'importlib-metadata; python_version<"3.8"',
+        "packaging~=23.1",
+        "setuptools # comment"
+    ]
+
+    [project.optional-dependencies]
+    pdf = ["ReportLab>=1.2"]
+    rest = ["pack ==1.1, ==1.3"]
+    """
+
+    dep_file = parse(content, file_type=filetypes.pyproject_toml)
+
+    assert len(dep_file.dependencies) == 6
+
+    assert dep_file.dependencies[0].name == "requests"
+    assert dep_file.dependencies[0].specs == SpecifierSet("")
+    assert dep_file.dependencies[0].dependency_type == "pyproject.toml"
+    assert dep_file.dependencies[0].section == "dependencies"
+
+    assert dep_file.dependencies[1].name == "importlib-metadata"
+    assert dep_file.dependencies[1].specs == SpecifierSet("")
+    assert dep_file.dependencies[1].dependency_type == "pyproject.toml"
+    assert dep_file.dependencies[1].section == "dependencies"
+
+    assert dep_file.dependencies[2].name == "packaging"
+    assert dep_file.dependencies[2].specs == SpecifierSet("~=23.1")
+    assert dep_file.dependencies[2].dependency_type == "pyproject.toml"
+    assert dep_file.dependencies[2].section == "dependencies"
+
+    assert dep_file.dependencies[3].name == "setuptools"
+    assert dep_file.dependencies[3].specs == SpecifierSet("")
+    assert dep_file.dependencies[3].dependency_type == "pyproject.toml"
+    assert dep_file.dependencies[3].section == "dependencies"
+
+    assert dep_file.dependencies[4].name == "ReportLab"
+    assert dep_file.dependencies[4].specs == SpecifierSet(">=1.2")
+    assert dep_file.dependencies[4].dependency_type == "pyproject.toml"
+    assert dep_file.dependencies[4].section == "pdf"
+
+    assert dep_file.dependencies[5].name == "pack"
+    assert dep_file.dependencies[5].specs == SpecifierSet("==1.1, ==1.3")
+    assert dep_file.dependencies[5].dependency_type == "pyproject.toml"
+    assert dep_file.dependencies[5].section == "rest"
+
+
+def test_pyproject_toml_no_deps() -> None:
+    content = """
+    [project]
+    name = "my_package"
+    authors = [
+        {name = "John Doe", email = "john.doe@email"},
+    ]
+    description = "My package description"
+    """
+
+    dep_file = parse(content, file_type=filetypes.pyproject_toml)
+
+    assert len(dep_file.dependencies) == 0
+
+
+def test_pyproject_toml_no_main_deps() -> None:
+    content = """
+    [project]
+    name = "my_package"
+    authors = [
+        {name = "John Doe", email = "john.doe@email"},
+    ]
+    description = "My package description"
+
+    [project.optional-dependencies]
+    pdf = ["ReportLab>=1.2"]
+    rest = ["pack ==1.1, ==1.3"]
+    """
+
+    dep_file = parse(content, file_type=filetypes.pyproject_toml)
+
+    assert len(dep_file.dependencies) == 2
+
+    assert dep_file.dependencies[0].name == "ReportLab"
+    assert dep_file.dependencies[0].specs == SpecifierSet(">=1.2")
+    assert dep_file.dependencies[0].dependency_type == "pyproject.toml"
+    assert dep_file.dependencies[0].section == "pdf"
+
+    assert dep_file.dependencies[1].name == "pack"
+    assert dep_file.dependencies[1].specs == SpecifierSet("==1.1, ==1.3")
+    assert dep_file.dependencies[1].dependency_type == "pyproject.toml"
+    assert dep_file.dependencies[1].section == "rest"
+
+
+def test_pyproject_toml_no_extra() -> None:
+    content = """
+    [project]
+    name = "my_package"
+    authors = [
+        {name = "John Doe", email = "john.doe@email"},
+    ]
+    description = "My package description"
+    dependencies = [
+        "requests",
+    ]
+    """
+
+    dep_file = parse(content, file_type=filetypes.pyproject_toml)
+
+    assert len(dep_file.dependencies) == 1
+
+    assert dep_file.dependencies[0].name == "requests"
+    assert dep_file.dependencies[0].specs == SpecifierSet("")
+    assert dep_file.dependencies[0].dependency_type == "pyproject.toml"
+    assert dep_file.dependencies[0].section == "dependencies"
