@@ -1,8 +1,8 @@
 #!/usr/bin/env python
-# -*- coding: utf-8 -*-
 
 """Tests for `dparse.updater`"""
 
+import pytest
 from dparse.parser import parse
 from dparse.updater import RequirementsTXTUpdater, CondaYMLUpdater, ToxINIUpdater, PipfileLockUpdater, PipfileUpdater
 from dparse import filetypes
@@ -37,6 +37,7 @@ def test_update_tox_ini():
     assert ToxINIUpdater.update(content=content, dependency=dep, version="2.9.5") == new_content
 
 
+@pytest.mark.conda
 def test_update_conda_yml():
     content = "name: my_env\n" \
               "dependencies:\n" \
@@ -435,7 +436,7 @@ def test_update_requirements_unfinished_line():
     assert RequirementsTXTUpdater.update(content=content, version=version,
                                          dependency=dep) == new_content
 
-
+@pytest.mark.pipenv
 def test_update_pipfile(monkeypatch):
     content = """[[source]]
 
@@ -455,12 +456,6 @@ django-allauth = "*"
 
 toml = "*"
     """
-    import pipenv.project
-    monkeypatch.setattr(
-        pipenv.project.pipfile.Pipfile,
-        'find',
-        lambda max_depth: '/tmp/MockPipFile'
-    )
     dep_file = parse(content=content, file_type=filetypes.pipfile)
     dep = dep_file.dependencies[0]
     new_content = PipfileUpdater.update(content, version="2.1", dependency=dep)
